Author: cazfi
Date: Tue Aug 16 07:19:10 2016
New Revision: 33609

URL: http://svn.gna.org/viewcvs/freeciv?rev=33609&view=rev
Log:
Prevented building advisor from randomly building, and thus potentially just 
moving, any small wonders.

See patch #7598

Modified:
    branches/S2_6/server/advisors/advbuilding.c

Modified: branches/S2_6/server/advisors/advbuilding.c
URL: 
http://svn.gna.org/viewcvs/freeciv/branches/S2_6/server/advisors/advbuilding.c?rev=33609&r1=33608&r2=33609&view=diff
==============================================================================
--- branches/S2_6/server/advisors/advbuilding.c (original)
+++ branches/S2_6/server/advisors/advbuilding.c Tue Aug 16 07:19:10 2016
@@ -324,10 +324,10 @@
     return;
   }
 
   /* Build the first thing we can think of (except a new palace). */
   improvement_iterate(pimprove) {
     if (can_city_build_improvement_now(pcity, pimprove)
-        && !building_has_effect(pimprove, EFT_CAPITAL_CITY)) {
+        && pimprove->genus != IG_SMALL_WONDER) {
       struct universal target = {
         .kind = VUT_IMPROVEMENT,
         .value = {.building = pimprove}
@@ -324,10 +324,10 @@
   }
 
-  /* Build the first thing we can think of (except a new palace). */
+  /* Build the first thing we can think of (except moving small wonder). */
   improvement_iterate(pimprove) {
     if (can_city_build_improvement_now(pcity, pimprove)


_______________________________________________
Freeciv-commits mailing list
Freeciv-commits@gna.org
https://mail.gna.org/listinfo/freeciv-commits

Reply via email to